@@ -21,7 +21,7 @@
 #ifndef __GDK_ASYNC_H__
 #define __GDK_ASYNC_H__
 
-#include <gdk/gdkdisplay.h>
+#include "gdkdisplay.h"
 #include <X11/Xlib.h>
 
 G_BEGIN_DECLS
@@ -54,10 +54,6 @@ void _gdk_x11_send_client_message_async (GdkDisplay            *display,
 					 XClientMessageEvent   *event_send,
 					 GdkSendXEventCallback  callback,
 					 gpointer               data);
-void _gdk_x11_set_input_focus_safe      (GdkDisplay            *display,
-					 Window                 window,
-					 int                    revert_to,
-					 Time                   time);
 
 gboolean _gdk_x11_get_window_child_info (GdkDisplay       *display,
 					 Window            window,
