@@ -21,6 +21,7 @@
 
 #include "config.h"
 #include <gtk/gtk.h>
+#include <gtk/gtkx.h>
 
 #include <string.h>
 #include <stdlib.h>
@@ -97,7 +98,7 @@ create_socket (void)
   
   Socket *socket = g_new (Socket, 1);
   
-  socket->box = gtk_vbox_new (FALSE, 0);
+  socket->box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   socket->socket = gtk_socket_new ();
   
@@ -249,7 +250,7 @@ void
 add_local_passive_child (GtkWidget *window)
 {
   Socket *socket;
-  GdkNativeWindow xid;
+  Window xid;
 
   socket = create_socket ();
   gtk_box_pack_start (GTK_BOX (box), socket->box, TRUE, TRUE, 0);
@@ -281,13 +282,22 @@ static void
 grab_window_toggled (GtkToggleButton *button,
 		     GtkWidget       *widget)
 {
+  GdkDevice *device = gtk_get_current_event_device ();
+
+  if (gdk_device_get_source (device) != GDK_SOURCE_KEYBOARD)
+    device = gdk_device_get_associated_device (device);
 
   if (gtk_toggle_button_get_active (button))
     {
       int status;
 
-      status = gdk_keyboard_grab (gtk_widget_get_window (widget),
-                                  FALSE, GDK_CURRENT_TIME);
+      status = gdk_device_grab (device,
+                                gtk_widget_get_window (widget),
+                                GDK_OWNERSHIP_NONE,
+                                FALSE,
+                                GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK,
+                                NULL,
+                                GDK_CURRENT_TIME);
 
       if (status != GDK_GRAB_SUCCESS)
 	g_warning ("Could not grab keyboard!  (%s)", grab_string (status));
@@ -295,7 +305,7 @@ grab_window_toggled (GtkToggleButton *button,
     } 
   else 
     {
-      gdk_keyboard_ungrab (GDK_CURRENT_TIME);
+      gdk_device_ungrab (device, GDK_CURRENT_TIME);
     }
 }
 
@@ -321,7 +331,7 @@ main (int argc, char *argv[])
   gtk_window_set_title (GTK_WINDOW (window), "Socket Test");
   gtk_container_set_border_width (GTK_CONTAINER (window), 0);
 
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
 
   menubar = gtk_menu_bar_new ();
@@ -375,13 +385,13 @@ main (int argc, char *argv[])
 		    G_CALLBACK (grab_window_toggled),
 		    window);
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
   entry = gtk_entry_new ();
   gtk_box_pack_start (GTK_BOX(hbox), entry, FALSE, FALSE, 0);
 
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
   box = hbox;
